/**
* This sample shows how to use the auto refresh acquisitions
**/

#include "stdafx.h"

int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT returnValue = 0;
	HANDLE boardHandle = NULL;
	ULONG readValue = 0;
	ULONG convertingTime = 0;
	BYTE channels[16] = {0};
	BYTE polarity[16] = {0};
	BYTE gain[16] = {0};
	BYTE inputMode = 0;
	PULONG values = NULL;

	/* initialize the acquisition with 4 channels */
	channels[0] = 0;
	channels[1] = 1;
	channels[2] = 2;
	channels[3] = 3;

	polarity[0] = PCIE3126_OUTPUT_MODE_BIPOLAR;
	polarity[1] = PCIE3126_OUTPUT_MODE_BIPOLAR;
	polarity[2] = PCIE3126_OUTPUT_MODE_BIPOLAR;
	polarity[3] = PCIE3126_OUTPUT_MODE_BIPOLAR;

	gain[0] = PCIE3126_GAIN_1;
	gain[1] = PCIE3126_GAIN_1;
	gain[2] = PCIE3126_GAIN_1;
	gain[3] = PCIE3126_GAIN_1;

	/* open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d opening the board \n", returnValue);
		_getch();
		return -1;
	}

	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n");
	printf("* This sample will initialize an acquisition using auto-refresh \n");
	printf("* The sequence is : \n");
	printf("*   - Channel 0, bipolar, gain 1 \n");
	printf("*   - Channel 1, bipolar, gain 1 \n");
	printf("*   - Channel 2, bipolar, gain 1 \n");
	printf("*   - Channel 3, bipolar, gain 1 \n");
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n\n");


	/* ask for input mode */
	ReadUlong("Select the input mode (0: Single-ended, 1: Differential) ", 0, 1, &readValue);
	switch ( readValue )
	{
		case 0:
			inputMode = PCIE3126_INPUT_MODE_SINGLE_ENDED;
			break;
		case 1:
			inputMode = PCIE3126_INPUT_MODE_DIFFERENTIAL;
			break;
	}

	/* set the input mode */
	returnValue = i_PCIe3126_SetAnalogInputMode( boardHandle, inputMode );
	if (returnValue != 0)
	{
		printf("Error %d in i_PCIe3126_SetAnalogInputMode \n", returnValue);
		i_PCIe3126_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* ask for converting time value */
	ReadUlong("What converting time do you want to use? (5 to 65535000) ", 5, 65535000, &convertingTime );

	/* start the autorefresh acquisition */
	returnValue = i_PCIe3126_InitAndStartAutoRefreshAcquisition (
		boardHandle,
		4,				/* number of channels in the sequence */
		channels,
		gain,
		polarity,				
		convertingTime,
		&values );

	/* error handling */
	if ( returnValue != 0 )
	{
		printf("Error %d in i_PCIe3126_InitAndStartAutoRefreshAcquisition \n", returnValue);
		i_PCIe3126_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	printf("Hit a key to exit.\n");
	/* 
	* Endless loop to read the value
	* To get the value we only have to get the value in the buffer
	*/
	do
	{
		Sleep(100);
		printf("0x%.4x 0x%.4x 0x%.4x 0x%.4x \t", values[0], values[1], values[2], values[3] );
		DisplayRunningStatus();
	}
	while( !_kbhit() );	

	/* stop the acquisition */
	returnValue = i_PCIe3126_StopAnalogAcquisition( boardHandle );
	if (returnValue != 0)
	{
		printf("Error %d in i_PCIe3126_StopAnalogAcquisition \n", returnValue);
		i_PCIe3126_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* close the board and return */
	returnValue = i_PCIe3126_CloseBoard(boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCIe3126_CloseBoard \n", returnValue);
		_getch();
		return -1;
	}

	/* success */
	return 0;
}

