/**
* This sample shows how to use the function Read1AnalogInput
**/

#include "stdafx.h"

/* entry point */
int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT	returnValue = 0;
	HANDLE boardHandle;
	ULONG readValue = 0;
	BYTE channel = 0;
	BYTE polarity = 0;
	BYTE gain = 0;
	BYTE inputMode = 0;
	WORD value = 0;
	BYTE maxAnalogInputs = 0;
	char displayBuffer[2048] = {0};

	/* open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d opening the board \n", returnValue);
		_getch();
		return -1;
	}

	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n");
	printf("* This sample enables to show how the i_PCIe3126_Read1AnalogInput works\n");
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n\n");

	/* get the analog input's number of the board */
	returnValue = i_PCIe3126_GetAnalogInputChannelsNbr( boardHandle, &maxAnalogInputs );
	if (returnValue != 0)
	{
		printf("Error %d in i_PCIe3126_GetNumberOfInputChannels \n", returnValue);
		i_PCIe3126_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* ask the input mode */
	ReadUlong("Select the input mode (0: Single-ended, 1: Differential) ", 0, 1, &readValue);
	switch ( readValue )
	{
		case 0:
			inputMode = PCIE3126_INPUT_MODE_SINGLE_ENDED;
			break;
		case 1:	
			inputMode = PCIE3126_INPUT_MODE_DIFFERENTIAL;
			break;
	}

	/* set the selected input mode */
	returnValue = i_PCIe3126_SetAnalogInputMode( boardHandle, inputMode );
	if (returnValue != 0)
	{
		printf("Error %d in i_PCIe3126_SetAnalogInputMode \n", returnValue);
		i_PCIe3126_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* ask the input channel */
	if ( inputMode == PCIE3126_INPUT_MODE_SINGLE_ENDED )
	{
		sprintf_s( displayBuffer, "Select the input channel (0 to %u) ", maxAnalogInputs-1 );
		ReadUlong(displayBuffer, 0, (maxAnalogInputs-1), &readValue);
	}
	else
	{
		sprintf_s( displayBuffer, "Select the input channel (0 to %u) ", (maxAnalogInputs/2)-1 );
		ReadUlong(displayBuffer, 0, (maxAnalogInputs/2)-1, &readValue);
	}
	channel = (UCHAR) readValue ;


	/* ask the gain */
	ReadUlong("Select the input gain (0: x1, 1: x2, 2: x5, 3: x10) ", 0, 3, &readValue);
	switch ( readValue )
	{
		case 0:
			gain = PCIE3126_GAIN_1;
			break;
		case 1:	
			gain = PCIE3126_GAIN_2;
			break;
		case 2:	
			gain = PCIE3126_GAIN_5;
			break;
		case 3:	
			gain = PCIE3126_GAIN_10;
			break;
	}

	/* ask the polarity */
	ReadUlong("Select the input polarity (0: Unipolar, 1: Bipolar) ", 0, 1, &readValue);
	switch ( readValue )
	{
		case 0:	
			polarity = PCIE3126_OUTPUT_MODE_UNIPOLAR;
			break;
		case 1:
			polarity = PCIE3126_OUTPUT_MODE_BIPOLAR;
			break;
	}

	printf("Hit a key to exit.\n");
	/* endless loop to read the value */
	do
	{
		returnValue = i_PCIe3126_Read1AnalogInput (
			boardHandle,
			channel,
			gain,
			polarity,
			5,								/* 5us converting time */
			0,								/* No interrupts */
			PCIE3126_SOFT_TRIGGER_DISABLED,	/* No software trigger */
			PCIE3126_EXT_TRIGGER_DISABLED,	/* No external trigger */
			&value );

		if ( returnValue != 0 )
		{
			printf("Error %d in i_PCIe3126_Read1AnalogInput \n", returnValue);
			i_PCIe3126_CloseBoard(boardHandle);
			_getch();
			return -1;
		}

		/* display value */
		printf("Channel %x value is 0x%.4x \t", channel, value);
		DisplayRunningStatus();
		Sleep(100);
	}
	while( !_kbhit() );

	/* close the board */
	returnValue = i_PCIe3126_CloseBoard(boardHandle);
	if ( returnValue != 0 )
	{
		printf("Error while closing board : %d \n", returnValue );
		_getch();
		return -1;
	}

	/* success */
	return 0;
}

