/**
* This sample shows how to use the GetTTLOutputsStatus function.
* The sample also uses the i_PCIe3126_SetTTLOutputsOn and i_PCIe3126_SetTTLOutputsOff functions.
* The sample uses DigitalOutputMemory
**/
#include "stdafx.h"

#define VALUE_CHANNEL_0(x)	( x & 0x1 )
#define VALUE_CHANNEL_1(x)	( (x >> 1) & 0x1 )
#define VALUE_CHANNEL_2(x)	( (x >> 2) & 0x1 )
#define VALUE_CHANNEL_3(x)	( (x >> 3) & 0x1 )
#define VALUE_CHANNEL_4(x)	( (x >> 4) & 0x1 )
#define VALUE_CHANNEL_5(x)	( (x >> 5) & 0x1 )
#define VALUE_CHANNEL_6(x)	( (x >> 6) & 0x1 )
#define VALUE_CHANNEL_7(x)	( (x >> 7) & 0x1 )

/**
* Function that enables to print the current status of the output
* @param boardHandle A handle to a device
* @return 0 on success, != 0 on error
**/
static INT PrintOutputStatus( HANDLE boardHandle, BYTE port )
{
	INT returnValue = 0;
	WORD outputStatus = 0;

	returnValue = i_PCIe3126_GetTTLOutputsStatus( boardHandle, port, &outputStatus );
	if ( returnValue != 0 )
	{
		printf("Error while getting TLL digital outputs status : %d \n", returnValue );
		return -1;
	}

	printf("\nCurrent output status :\n");
	printf("____________________________________________________________\n");
	if ( port == PCIE3126_PORT_PROGRAMMABLE)
		printf("|Channel 16 \t |Channel 17 \t |Channel 18 \t |Channel 19|\n");
	else
		printf("|Channel 0 \t |Channel 1 \t |Channel 2 \t |Channel 3|\n");
	/* print the outputs status */
	printf("|%d \t\t |%d \t\t |%d \t\t |%d        |\n",
		VALUE_CHANNEL_0(outputStatus),
		VALUE_CHANNEL_1(outputStatus),
		VALUE_CHANNEL_2(outputStatus),
		VALUE_CHANNEL_3(outputStatus));
	printf("____________________________________________________________\n");
	if ( port == PCIE3126_PORT_PROGRAMMABLE)
		printf("|Channel 20 \t |Channel 21 \t |Channel 22 \t |Channel 23|\n");
	else
		printf("|Channel 4 \t |Channel 5 \t |Channel 6 \t |Channel 7|\n");
	/* print the outputs status */
	printf("|%d \t\t |%d \t\t |%d \t\t |%d        |\n\n\n",
		VALUE_CHANNEL_4(outputStatus),
		VALUE_CHANNEL_5(outputStatus),
		VALUE_CHANNEL_6(outputStatus),
		VALUE_CHANNEL_7(outputStatus));

	return 0;
}

/* entry point */
int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT returnValue = 0;
	HANDLE boardHandle = NULL;
	WORD mask = 0; /* all output to 0 */
	BYTE port = 0;
	ULONG readValue = 0;

	/* call the util method to open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error while opening the board : %d \n", (int) returnValue);
		_getch();
		return -1;
	}

	/* ask the port to use */
	ReadUlong("Which port do you want to use? (0: Output port, 1: Programmable port) ",0,1,&readValue);
	switch ( readValue ) 
	{
		case 0:
			port = PCIE3126_PORT_OUTPUT;
			break;
		case 1:
			port = PCIE3126_PORT_PROGRAMMABLE;
			break;
	}

	if ( port == PCIE3126_PORT_PROGRAMMABLE)
	{
		/* set the programmable port configuration as input */
		returnValue = i_PCIe3126_SetTTLPortConfiguration( boardHandle, PCIE3126_TTL_OUTPUT );
		if (returnValue != 0)
		{
			printf("Error %d in i_PCIe3126_SetTTLPortConfiguration \n", returnValue);
			i_PCIe3126_CloseBoard(boardHandle);
			_getch();
			return -1;
		}
		printf("Bidirectional port set as output \n");
	}

	/* informations about the sample */
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n");
	printf("* This sample will use the TTL output (port 0) of the board, with digital\n");
	printf("* memory activated. \n");
	printf("* Use the key 0 to 7 of you key board to change the status of an output. \n");
	printf("* Use the key ESC of you key board to exit the sample. \n");
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n\n");

	/* set the digital output memory to on*/
	returnValue = i_PCIe3126_SetDigitalOutputMemoryOn( boardHandle );
	if ( returnValue != 0 )
	{
		printf("Error while setting digital output memory to on : %d \n", (int) returnValue);
		i_PCIe3126_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* set all the outputs to 0 */
	returnValue = i_PCIe3126_SetTTLOutputsOff( boardHandle, port, 0xFF );
	if ( returnValue != 0 )
	{
		printf("Error while setting ttl digital output to off : %d \n", (int) returnValue);
		i_PCIe3126_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* display the current output status */
	if ( PrintOutputStatus( boardHandle , port ) != 0 )
	{
		i_PCIe3126_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* endless loop */
	for(;;)
	{
		/* do the user hit a keyboard touch ? */
		if ( _kbhit() )
		{
			int hitChar = _getch();
			switch ( hitChar )
			{
				/* ESC */
				case 27:
					i_PCIe3126_CloseBoard(boardHandle);
					return 0;
				/* 0 to 7 */
				case 48:
				case 49:
				case 50:
				case 51:
				case 52:
				case 53:
				case 54:
				case 55:
					{
						int channel = ( hitChar - 48 );
						/* check if we have to set to on or to off */
						if ( (mask & ( 1 << channel )) == 0 )
						{
							/* set to on */
							returnValue = i_PCIe3126_SetTTLOutputsOn( boardHandle, port, (WORD)( 1 << channel ) );
							if ( returnValue != 0 )
							{
								printf("Error while calling i_PCIe3126_SetTTLOutputsOn : %d \n", returnValue );
								i_PCIe3126_CloseBoard(boardHandle);
								return -1;
							}
							/* update the internal value */
							mask |= ( 1 << channel );
						}
						else
						{
							/* set to off */
							returnValue = i_PCIe3126_SetTTLOutputsOff( boardHandle, port, (WORD)( 1 << channel ) );
							if ( returnValue != 0 )
							{
								printf("Error while calling i_PCIe3126_SetTTLOutputsOff : %d \n", returnValue );
								i_PCIe3126_CloseBoard(boardHandle);
								return -1;
							}
							/* update the internal value */
							mask &= ~( 1 << channel );
						}

						/* display the current output status */
						if ( PrintOutputStatus( boardHandle, port ) != 0 )
						{
							i_PCIe3126_CloseBoard(boardHandle);
							return -1;
						}
					}
					break;
			}
			Sleep(100);
		}
	}
}

