using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.InteropServices;

namespace PCIe3126_NET
{
    /// <summary>
    /// Contains the call to the DLL functions
    /// </summary>
    public class DllImport
    {
        /// <summary>
        /// Definition of the function that must be given to use the interruption of the board
        /// </summary>
        /// <param name="handle"></param>
        /// <param name="fifoStatus"></param>
        /// <param name="source">Source of the interruption. 1: digital input, 2: digital output, 4: timer, 8: counter</param>
        /// <param name="mask"></param>
        /// <param name="size"></param>
        /// <param name="args"></param>
        [UnmanagedFunctionPointer(CallingConvention.Cdecl)]
        public delegate void InterruptFunctionEventHandler(IntPtr handle,
                                                            byte overflow,
                                                            uint source,
                                                            uint mask,
                                                            IntPtr args,
                                                            uint argsSize
                                                            );

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_GetNumberOfBoards(ref byte boardNumber );

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_OpenBoardViaIndex(byte index, ref IntPtr deviceHandle );

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_CloseBoard(IntPtr deviceHandle);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_SetBoardIntRoutine(IntPtr h_DeviceHandle, [MarshalAs(UnmanagedType.FunctionPtr)] InterruptFunctionEventHandler interruptFunction);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_ResetBoardIntRoutine(IntPtr h_DeviceHandle);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_SetDigitalOutputMemoryOn(IntPtr deviceHandle);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_SetDigitalOutputMemoryOff(IntPtr deviceHandle);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Set1DigitalOutputOn(IntPtr deviceHandle, byte channel);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Set1DigitalOutputOff(IntPtr deviceHandle, byte channel);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Set4DigitalOutputsOn(IntPtr deviceHandle, byte value);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Set4DigitalOutputsOff(IntPtr deviceHandle, byte value);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Get1DigitalOutputStatus(IntPtr deviceHandle, byte channel, ref byte outputStatus);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Get4DigitalOutputsStatus(IntPtr deviceHandle, ref byte outputStatus);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Read1DigitalInput(IntPtr deviceHandle, byte channel, ref byte value);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Read4DigitalInputs(IntPtr deviceHandle, ref byte value);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_InitAndStartTimer(IntPtr deviceHandle, byte timerNb, byte mode, byte timeBase, byte outputMode, byte interruptEnabled, ushort reloadValue, byte watchdogEnabled);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_StopTimer(IntPtr deviceHandle, byte timerNb);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_ReadTimerStatus(IntPtr deviceHandle, byte timerNb, ref byte status, ref byte softwareTriggerStatus, ref ushort value);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_TriggerTimer(IntPtr deviceHandle, byte timerNb);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_SetAnalogInputMode(IntPtr deviceHandle, byte inputMode);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_GetAnalogInputMode(IntPtr deviceHandle, ref byte inputMode);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_InitAndStartAnalogInputSequence(IntPtr deviceHandle,
            uint sequenceCount, 
            uint sequenceBeforeInterrupt,
            byte channelCount,
            byte[] channelArray,
            byte[] gainArray,
            byte[] polarityArray,
            uint convertingTime,
            uint delayTime,
            byte softTriggerMode,
            byte extTriggerMode,
            uint sequenceTriggerCount);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_StopAnalogAcquisition(IntPtr deviceHandle);

        [DllImport("PCIe3126.dll")]
        public static extern int l_PCIe3126_ReadSequenceData(IntPtr deviceHandle, uint size, ushort[] data);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_ReadMoreAnalogInputs(IntPtr deviceHandle,
            byte channelCount,
            byte[] channelArray,
            byte[] gainArray,
            byte[] polarityArray,
            uint convertingTime,
            byte interruptFlag,
            byte softTriggerMode,
            byte extTriggerMode,
            ushort[] value);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Read1AnalogInput(IntPtr deviceHandle,
            byte channelIndex,
            byte gain,
            byte polarity,
            uint convertingTime,
            byte interruptFlag,
            byte softTriggerMode,
            byte extTriggerMode,
            ref ushort value);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_InitAndStartAutoRefreshAcquisition(IntPtr deviceHandle,
            byte channelCount,
            byte[] channelArray,
            byte[] gainArray,
            byte[] polarityArray,
            uint convertingTime,
            ref IntPtr value);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_TriggerAnalogAcquisition(IntPtr deviceHandle);

        [DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_GetAnalogInputChannelsNbr(IntPtr deviceHandle, ref byte analogInputCount);
		
		[DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_Write1AnalogOutput(IntPtr h_DeviceHandle, byte uc_Channel, byte uc_Polarity, ushort us_Value);

		[DllImport("PCIe3126.dll")]
        public static extern short i_PCIe3126_WriteMoreAnalogOutputs(IntPtr h_DeviceHandle, byte uc_ChannelNbr, byte[] puc_Channel, byte[] puc_Polarity, ushort[] pus_Value);
		
#region "LoadLogic"

		[DllImport("PCIe3126.dll")]
		public static extern short i_PCIe3126_LoadLogicCommand(IntPtr deviceHandle, UInt32 command);

		[DllImport("PCIe3126.dll")]
		public static extern short i_PCIe3126_LoadLogicWrite(IntPtr deviceHandle, UInt32 data);

		[DllImport("PCIe3126.dll")]
		public static extern short i_PCIe3126_LoadLogicRead(IntPtr deviceHandle, out UInt32 data);

		[DllImport("PCIe3126.dll")]
		public static extern short i_PCIe3126_GetLoadLogicStatus(IntPtr deviceHandle, out Byte status);

		[DllImport("PCIe3126.dll")]
		public static extern short i_PCIe3126_GetFirmwareVersion(IntPtr deviceHandle, out UInt32 version);

#endregion
    }
}
