function [returnValue] = i_PCIe3121_mexInitAndStartAnalogInputSequence(deviceHandle, sequenceCount, sequenceBeforeInterrupt, channelCount, channels, gain, polarity, convertingTime, interruptFlag, softTriggerMode, extTriggerMode, sequenceTriggerCount)
% i_PCIe3121_mexInitAndStartAnalogInputSequence
%
% Initializes and starts an analog acquisition 
% To use this function you must set an interrupt routine where you will handle the data, and you must also define the input mode. 
% Gain acts as a multiplier for the input voltage. Possible gain values are :
% 
%   0 : x1 gain, input range is between -10V and 10V (bipolar)
%   1 : x2 gain, input range is between -5V and 5V (bipolar)
%   2 : x5 gain, input range is between -2V and 2V (bipolar)
%   3 : x10 gain, input range is between -1V and 1V (bipolar)
% 
% The converting time stands for the time spent to acquire one channel. The time to acquire a sequence is dw_ConvertingTime * b_ChannelCount 
% The software trigger is a combination of 2 parameters
% 
% The first one enables or disabled the trigger
% 
%   0 : The trigger is disabled
%   1 : The trigger is enabled
% 
% The trigger type is selected with one of the following parameters
% 
%    0 : The acquisition starts when the trigger is set
%    8 : A pre-defined number of sequence is acquired : dw_SequenceTriggerCount
%   12 : One whole sequence is read for each trigger
% 
% 
% The external trigger is a combination of the following parameters :
% 
% The first one defines the trigger edge
% 
%   0 : Trigger is disabled
%   1 : Triggers on falling edge
%   2 : Triggers on rising edge
%   3 : Triggers on both edges
% 
% The second one defines the trigger type
% 
%    0 : The acquisition starts when the trigger is set
%    8 : A pre-defined number of sequence is acquired : dw_SequenceTriggerCount
%   12 : One whole sequence is read for each trigger
% 
% 
%
% Input parameters:
%    deviceHandle              "Handle of the board"
%    sequenceCount             "The total number of sequences to acquire. Set it to 0 if you want to use continuous acquisition (i.e. acquire until stopped)"
%    sequenceBeforeInterrupt   "Specify The number of sequences to wait before generating an interruption. For high frequency, set a high number (512 if using maximum frequency for example)."
%    channelCount              "The number of channels to be acquired"
%    channels                  "An array containing the channels to be acquired"
%    gain                      "An array containing the gains applied to the channels (0 -> x1, 1 -> x2, 2 -> x5, 3 -> x10)"
%    polarity                  "An array containing the polarities of the channels (0 -> unipolar, 1 -> bipolar)"
%    convertingTime            "The length of time allocated to the A/D conversion (in microseconds)"
%    interruptFlag             "0 -> Interrupts disabled, 1 -> Interrupts enabled"
%    softTriggerMode           "Please refer to the function description for further information"
%    extTriggerMode            "Please refer to the function description for further information"
%    sequenceTriggerCount      "If you choose a trigger with mode PCIE3121_TRIGGER_SEQUENCE_TRIGGER, it defines The number of sequence to acquire when a trigger occurs (1 to 0xFFFFFFFF). If not in use, give 0."
%
% Output parameters:
%    returnValue             "Value returned by the function"
%
%Example:
% // Add an example here

[returnValue] = i_PCIe3121_mexInitAndStartAnalogInputSequence(deviceHandle, sequenceCount, sequenceBeforeInterrupt, channelCount, channels, gain, polarity, convertingTime, interruptFlag, softTriggerMode, extTriggerMode, sequenceTriggerCount);
