//##protect##"FileHeader"
/** @file i_PCIe3121_mexRead1AnalogInput.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 01.11.2012
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCIe3121_mexRead1AnalogInput MEX file
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "PCIe3121.h"
#include "mex.h"
#include "matrix.h"

/* i_PCIe3121_mexRead1AnalogInput */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE channel = 0;
	BYTE gain = 0;
	BYTE polarity = 0;
	DWORD convertingTime = 0;
	BYTE interruptFlag = 0;
	BYTE softTriggerMode = 0;
	BYTE extTriggerMode = 0;
	WORD *channelValue = mxCalloc(1, sizeof(WORD));
//##protect##"i_PCIe3121_mexRead1AnalogInput_VariablesDefinition"
//##protect##"i_PCIe3121_mexRead1AnalogInput_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 8)
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexRead1AnalogInput:nrhs", "8 inputs are required.\n");
	if (nlhs != 2)
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexRead1AnalogInput:nlhs", "2 outputs are required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(LONG)mxGetScalar(prhs[0]);
	channel = (BYTE)mxGetScalar(prhs[1]);
	gain = (BYTE)mxGetScalar(prhs[2]);
	polarity = (BYTE)mxGetScalar(prhs[3]);
	convertingTime = (DWORD)mxGetScalar(prhs[4]);
	interruptFlag = (BYTE)mxGetScalar(prhs[5]);
	softTriggerMode = (BYTE)mxGetScalar(prhs[6]);
	extTriggerMode = (BYTE)mxGetScalar(prhs[7]);

	/* Check of the values of the input parameters */
	if ((channel < 0 || channel > 15))
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexRead1AnalogInput:nlhs", "The channel input must be between 0 and 15.\n");
	if ((gain < 0 || gain > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexRead1AnalogInput:nlhs", "The gain input must be between 0 and 3.\n");
	if ((polarity < 0 || polarity > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexRead1AnalogInput:nlhs", "The polarity input must be between 0 and 1.\n");
	if ((convertingTime < 5 || convertingTime > 65535000))
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexRead1AnalogInput:nlhs", "The convertingTime input must be between 5 and 65535000.\n");
	if ((interruptFlag < 0 || interruptFlag > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexRead1AnalogInput:nlhs", "The interruptFlag input must be between 0 and 1.\n");
	if ((softTriggerMode < 0 || softTriggerMode > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexRead1AnalogInput:nlhs", "The softTriggerMode input must be between 0 and 1.\n");
	if ((extTriggerMode < 0 || extTriggerMode > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexRead1AnalogInput:nlhs", "The extTriggerMode input must be between 0 and 3.\n");

//##protect##"i_PCIe3121_mexRead1AnalogInput_Start"
//##protect##"i_PCIe3121_mexRead1AnalogInput_Start"

	/* Call of the C function */
	*returnValue = i_PCIe3121_Read1AnalogInput(deviceHandle, channel, gain, polarity, convertingTime, interruptFlag, softTriggerMode, extTriggerMode, channelValue);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);
	plhs[1] = mxCreateNumericArray(0, NULL, mxUINT16_CLASS, mxREAL);
	mxSetData(plhs[1], channelValue);  mxSetM(plhs[1], 1);  mxSetN(plhs[1], 1);

//##protect##"i_PCIe3121_mexRead1AnalogInput_End"
//##protect##"i_PCIe3121_mexRead1AnalogInput_End"
}
