function [returnValue, channelValue] = i_PCIe3121_mexRead1AnalogInput(deviceHandle, channel, gain, polarity, convertingTime, interruptFlag, softTriggerMode, extTriggerMode)
% i_PCIe3121_mexRead1AnalogInput
%
% Reads the value of one analog input from the board
% You must call the set analog input mode function before calling this function. 
% Gain acts as a multiplier for the input voltage. Possible gain values are :
% 
%   0 : x1 gain, input range is between -10V and 10V (bipolar)
%   1 : x2 gain, input range is between -5V and 5V (bipolar)
%   2 : x5 gain, input range is between -2V and 2V (bipolar)
%   3 : x10 gain, input range is between -1V and 1V (bipolar)
% 
% The converting time stands for the time spent to acquire one channel. The time to acquire a sequence is ul_ConvertingTime * uc_ChannelCount 
% The software trigger is a combination of 2 parameters
% 
% The first one enables or disables the trigger
% 
%   0 : The trigger is disabled
%   1 : The trigger is enabled
% 
% The trigger type is selected with one of the following parameters
% 
%   0 : The acquisition starts when the trigger is set
% 
% 
% The external trigger is a combination of the following parameters :
% 
% The first one defines the trigger edge
% 
%   0 : Trigger is disabled
%   1 : Triggers on falling edge
%   2 : Triggers on rising edge
%   3 : Triggers on both edges
% 
% The second one defines the trigger type
% 
%   0 : The acquisition starts when the trigger is set
% 
% 
% If the interrupts are enabled, the function returns, and the value can be read in the interrupt routine once available. 
% If the interrupts are disabled, the function waits for the results and return the values in the pus_ChannelValue parameter. 
%
% Input parameters:
%    deviceHandle              "Handle of the board"
%    channel                   "The channel to be acquired (single-ended -> 0 to 15, differential -> 0 to 7)"
%    gain                      "The gain applied to the channel (0 -> x1, 1 -> x2, 2 -> x5, 3 -> x10)"
%    polarity                  "The polarity of the channel (0 -> unipolar, 1 -> bipolar)"
%    convertingTime            "The length of time allocated to the A/D conversion (in microseconds)"
%    interruptFlag             "0 -> Interrupts disabled, 1 -> Interrupts enabled"
%    softTriggerMode           "Please refer to the function description for further information"
%    extTriggerMode            "Please refer to the function description for further information"
%
% Output parameters:
%    returnValue             "Value returned by the function"
%    channelValue              "The acquired value, if interrupts are disabled"
%
%Example:
% // Add an example here

[returnValue, channelValue] = i_PCIe3121_mexRead1AnalogInput(deviceHandle, channel, gain, polarity, convertingTime, interruptFlag, softTriggerMode, extTriggerMode);
