//##protect##"FileHeader"
/** @file i_PCIe3121_mexWriteMoreAnalogOutputs.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 01.11.2012
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCIe3121_mexWriteMoreAnalogOutputs MEX file
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "PCIe3121.h"
#include "mex.h"
#include "matrix.h"

/* i_PCIe3121_mexWriteMoreAnalogOutputs */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE channelCount = 0;
	DWORD i = 0;
	BYTE channels[8];
	BYTE polarity[8];
	WORD values[8];
//##protect##"i_PCIe3121_mexWriteMoreAnalogOutputs_VariablesDefinition"
//##protect##"i_PCIe3121_mexWriteMoreAnalogOutputs_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 5)
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexWriteMoreAnalogOutputs:nrhs", "5 inputs are required.\n");
	if (nlhs != 1)
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexWriteMoreAnalogOutputs:nlhs", "1 output is required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(LONG)mxGetScalar(prhs[0]);
	channelCount = (BYTE)mxGetScalar(prhs[1]);
	for (i = 0; i < 8; i++)
		channels[i] = (BYTE)mxGetPr(prhs[2])[i];
	for (i = 0; i < 8; i++)
		polarity[i] = (BYTE)mxGetPr(prhs[3])[i];
	for (i = 0; i < 8; i++)
		values[i] = (WORD)mxGetPr(prhs[4])[i];

	/* Check of the values of the input parameters */
	if ((channelCount < 0 || channelCount > 8))
		mexErrMsgIdAndTxt("MyToolbox:i_PCIe3121_mexWriteMoreAnalogOutputs:nlhs", "The channelCount input must be between 0 and 8.\n");

//##protect##"i_PCIe3121_mexWriteMoreAnalogOutputs_Start"
//##protect##"i_PCIe3121_mexWriteMoreAnalogOutputs_Start"

	/* Call of the C function */
	*returnValue = i_PCIe3121_WriteMoreAnalogOutputs(deviceHandle, channelCount, channels, polarity, values);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);

//##protect##"i_PCIe3121_mexWriteMoreAnalogOutputs_End"
//##protect##"i_PCIe3121_mexWriteMoreAnalogOutputs_End"
}
